"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_unistyles_1 = require("react-native-unistyles");
const enums_1 = require("@procyon/types/enums");
const Button = (props) => {
    const { disabled, onClick, status = enums_1.StatusEnum.none, size = enums_1.SizeEnum.md, label, style, blank = false, } = props;
    const { styles } = (0, react_native_unistyles_1.useStyles)(stylesSheet, {
        status,
        blank,
        size,
        disabled,
    });
    return (react_1.default.createElement(react_native_1.Pressable, { "aria-label": "button", style: (state) => [styles.procyon_button_container(state), style === null || style === void 0 ? void 0 : style.container], onPress: () => onClick === null || onClick === void 0 ? void 0 : onClick(), disabled: disabled },
        react_1.default.createElement(react_native_1.Text, { style: [styles.procyon_button_text(status), style === null || style === void 0 ? void 0 : style.text] }, label)));
};
exports.Button = Button;
const stylesSheet = (0, react_native_unistyles_1.createStyleSheet)((theme) => ({
    procyon_button_container: ({ pressed }) => {
        const variantForStatus = (status) => ({
            shadowColor: theme.components.button[status].border,
            borderColor: theme.components.button[status].border,
            backgroundColor: theme.components.button[status].background,
        });
        const variantForSize = (size) => ({
            padding: theme.spacing[size],
            marginVertical: theme.spacing[size],
        });
        return Object.assign(Object.assign({ display: 'flex', flexShrink: 1, justifyContent: 'center', alignItems: 'center', width: '100%', minWidth: 50, borderRadius: theme.spacing.md, textTransform: 'uppercase', fontWeight: 'normal', userSelect: 'none', borderWidth: 1, marginHorizontal: 'auto', shadowOffset: { width: 0, height: 3 }, shadowOpacity: 1, shadowRadius: 0 }, (pressed && {
            shadowOffset: { width: 0, height: 0 },
            transform: 'translateY(3px)',
        })), { variants: {
                size: {
                    [enums_1.SizeEnum.sm]: variantForSize(enums_1.SizeEnum.sm),
                    [enums_1.SizeEnum.md]: variantForSize(enums_1.SizeEnum.md),
                    [enums_1.SizeEnum.lg]: variantForSize(enums_1.SizeEnum.lg),
                    [enums_1.SizeEnum.xl]: variantForSize(enums_1.SizeEnum.xl),
                },
                status: {
                    [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                    [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                    [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                    [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                    [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                },
                disabled: {
                    true: {
                        shadowColor: theme.components.button.disabled.border,
                        borderColor: theme.components.button.disabled.border,
                        backgroundColor: theme.components.button.disabled.background,
                        shadowOffset: 0,
                    },
                },
                blank: {
                    true: {
                        shadowColor: theme.components.button.none.border,
                        borderColor: theme.components.button.none.border,
                        backgroundColor: theme.components.button.none.background,
                    },
                },
            } });
    },
    procyon_button_text: (status) => {
        const variantForStatus = (status) => ({
            color: theme.components.button[status].color,
        });
        const variantForStatusIfBlank = () => ({
            color: status === enums_1.StatusEnum.none
                ? theme.components.button.none.color
                : theme.components.button[status].background,
        });
        const variantForSize = (size) => {
            let fontSize = 0;
            switch (size) {
                case enums_1.SizeEnum.sm:
                    fontSize = 14;
                    break;
                case enums_1.SizeEnum.md:
                    fontSize = 16;
                    break;
                case enums_1.SizeEnum.lg:
                    fontSize = 20;
                    break;
                case enums_1.SizeEnum.xl:
                    fontSize = 26;
                    break;
            }
            return {
                fontSize,
            };
        };
        return {
            fontFamily: theme.fontFamily,
            variants: {
                size: {
                    [enums_1.SizeEnum.sm]: variantForSize(enums_1.SizeEnum.sm),
                    [enums_1.SizeEnum.md]: variantForSize(enums_1.SizeEnum.md),
                    [enums_1.SizeEnum.lg]: variantForSize(enums_1.SizeEnum.lg),
                    [enums_1.SizeEnum.xl]: variantForSize(enums_1.SizeEnum.xl),
                },
                status: {
                    [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                    [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                    [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                    [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                    [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                },
                disabled: {
                    true: {
                        color: theme.components.button.disabled.color,
                    },
                },
                blank: {
                    true: variantForStatusIfBlank(),
                },
            },
        };
    },
}));
