"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toasters = exports.ToastersPosition = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_unistyles_1 = require("react-native-unistyles");
const utils_1 = require("@procyon/utils");
const Message_1 = require("../../Message");
const hooks_1 = require("../hooks");
var ToastersPosition;
(function (ToastersPosition) {
    ToastersPosition["BottomCenter"] = "bottomCenter";
    ToastersPosition["BottomLeft"] = "bottomLeft";
    ToastersPosition["BottomRight"] = "bottomRight";
    ToastersPosition["LeftCenter"] = "leftCenter";
    ToastersPosition["RightCenter"] = "rightCenter";
    ToastersPosition["TopCenter"] = "topCenter";
    ToastersPosition["TopLeft"] = "topLeft";
    ToastersPosition["TopRight"] = "topRight";
})(ToastersPosition || (exports.ToastersPosition = ToastersPosition = {}));
const Toasters = ({ position }) => {
    const { toasters } = (0, hooks_1.useToaster)();
    const { styles } = (0, react_native_unistyles_1.useStyles)(styleSheet, {
        position,
    });
    if ((0, utils_1.isNilOrEmpty)(toasters)) {
        return null;
    }
    return (react_1.default.createElement(react_native_1.View, { style: [styles.procyon_toasters_container] }, Object.keys(toasters).map((toasterId) => {
        const toaster = toasters[toasterId];
        return (react_1.default.createElement(Message_1.Message, { key: toasterId, status: toaster.status, title: toaster.title }, toaster.message));
    })));
};
exports.Toasters = Toasters;
const styleSheet = (0, react_native_unistyles_1.createStyleSheet)(() => ({
    procyon_toasters_container: {
        position: 'absolute',
        zIndex: 10,
        variants: {
            position: {
                [ToastersPosition.TopLeft]: {
                    top: 5,
                    left: 5,
                },
                [ToastersPosition.TopCenter]: {
                    top: 5,
                    left: '50%',
                    transform: [
                        {
                            translateX: -50,
                            translateY: 0,
                        },
                    ],
                },
                [ToastersPosition.TopRight]: {
                    top: 5,
                    right: 5,
                },
                [ToastersPosition.RightCenter]: {
                    top: '50%',
                    transform: [
                        {
                            translateY: -50,
                            translateX: 0,
                        },
                    ],
                    right: 5,
                },
                [ToastersPosition.BottomRight]: {
                    bottom: 5,
                    right: 5,
                },
                [ToastersPosition.BottomCenter]: {
                    bottom: 5,
                    left: '50%',
                    transform: [
                        {
                            translateX: -50,
                            translateY: 0,
                        },
                    ],
                },
                [ToastersPosition.BottomLeft]: {
                    bottom: 5,
                    left: 5,
                },
                [ToastersPosition.LeftCenter]: {
                    top: '50%',
                    transform: [
                        {
                            translateY: -50,
                            translateX: 0,
                        },
                    ],
                    left: 5,
                },
            },
        },
    },
}));
